@@ -61,9 +61,11 @@ item(_MARCO_TOGGLE_VERBOSE)
 item(_GTK_THEME_VARIANT)
 item(_GTK_FRAME_EXTENTS)
 item(_GTK_SHOW_WINDOW_MENU)
+item(_GTK_WORKAREAS)
 item(_MATE_PANEL_ACTION)
 item(_MATE_PANEL_ACTION_MAIN_MENU)
 item(_MATE_PANEL_ACTION_RUN_DIALOG)
+item(_GNOME_WM_STRUT_AREA)
 item(_MARCO_SENTINEL)
 item(_MARCO_VERSION)
 item(WM_CLIENT_MACHINE)
