@@ -45,6 +45,8 @@
 #define _XOPEN_SOURCE /* for putenv() and some signal-related functions */
 
 #include <config.h>
+#include <glib/gi18n-lib.h>
+
 #include "main.h"
 #include "util.h"
 #include "display-private.h"
@@ -110,33 +112,6 @@ log_handler (const gchar   *log_domain,
   meta_print_backtrace ();
 }
 
-/**
- * Prints the version notice. This is shown when Marco is called
- * with the --version switch.
- */
-static void
-version (void)
-{
-  const int latest_year = 2009;
-  char yearbuffer[256];
-  GDate date;
-
-  /* this is all so the string to translate stays constant.
-   * see how much we love the translators.
-   */
-  g_date_set_dmy (&date, 1, G_DATE_JANUARY, latest_year);
-  if (g_date_strftime (yearbuffer, sizeof (yearbuffer), "%Y", &date)==0)
-    /* didn't work?  fall back to decimal representation */
-    g_sprintf (yearbuffer, "%d", latest_year);
-
-  g_print (_("marco %s\n"
-             "Copyright (C) 2001-%s Havoc Pennington, Red Hat, Inc., and others\n"
-             "This is free software; see the source for copying conditions.\n"
-             "There is NO warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n"),
-           VERSION, yearbuffer);
-  exit (0);
-}
-
 /**
  * Prints a list of which configure script options were used to
  * build this copy of Marco. This is actually always called
@@ -471,7 +446,10 @@ main (int argc, char **argv)
   meta_set_syncing (meta_args.sync || (g_getenv ("MARCO_SYNC") != NULL));
 
   if (meta_args.print_version)
-    version ();
+    {
+      g_print ("%s\n", PACKAGE_STRING);
+      exit (EXIT_SUCCESS);
+    }
 
   meta_select_display (meta_args.display_name);
 
@@ -489,7 +467,6 @@ main (int argc, char **argv)
   meta_prefs_init ();
   meta_prefs_add_listener (prefs_changed_callback, NULL);
 
-
 #if 1
 
   for (i=0; i<G_N_ELEMENTS(log_domains); i++)
