@@ -45,6 +45,8 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
 
+G_BEGIN_DECLS
+
 typedef struct _MetaGroup MetaGroup;
 typedef struct _MetaWindowQueue MetaWindowQueue;
 
@@ -88,6 +90,7 @@ typedef enum {
   META_TILE_CYCLE_50,
   META_TILE_CYCLE_33,
   META_TILE_CYCLE_25,
+  META_TILE_CYCLE_100,
   META_TILE_CYCLE_75,
   META_TILE_CYCLE_66
 } MetaTileCycle;
@@ -96,6 +99,8 @@ typedef enum {
 
 struct _MetaWindow
 {
+  GObject parent;
+
   MetaDisplay *display;
   MetaScreen *screen;
   MetaWorkspace *workspace;
@@ -512,7 +517,6 @@ void        meta_window_resize_with_gravity (MetaWindow  *window,
                                              int          h,
                                              int          gravity);
 
-
 /* Return whether the window would be showing if we were on its workspace */
 gboolean    meta_window_showing_on_its_workspace (MetaWindow *window);
 
@@ -582,7 +586,6 @@ void meta_window_send_icccm_message (MetaWindow *window,
                                      Atom        atom,
                                      guint32     timestamp);
 
-
 void     meta_window_move_resize_request(MetaWindow *window,
                                          guint       value_mask,
                                          int         gravity,
@@ -663,7 +666,6 @@ void     meta_window_foreach_ancestor         (MetaWindow            *window,
                                                void                  *data);
 MetaWindow* meta_window_find_root_ancestor    (MetaWindow *window);
 
-
 void meta_window_begin_grab_op (MetaWindow *window,
                                 MetaGrabOp  op,
                                 gboolean    frame_action,
@@ -702,4 +704,6 @@ void meta_window_update_net_wm_type (MetaWindow *window);
 
 gboolean meta_window_can_tile (MetaWindow *window);
 
-#endif
+G_END_DECLS
+
+#endif /* META_WINDOW_PRIVATE_H */
