@@ -305,15 +305,18 @@ get_local_pid (MetaWindow *window)
   long i;
 
   pid = -1;
+  if (window->display->have_xres == FALSE)
+    return pid;
 
   spec.client = window->xwindow;
   spec.mask = XRES_CLIENT_ID_PID_MASK;
 
-  XResQueryClientIds (window->display->xdisplay,
-                      1,
-                      &spec,
-                      &num_ids,
-                      &client_ids);
+  if (!XResQueryClientIds (window->display->xdisplay,
+                          1,
+                          &spec,
+                          &num_ids,
+                          &client_ids))
+      return pid;
 
   for (i = 0; i < num_ids; i++)
     {
@@ -486,7 +489,7 @@ set_title_text (MetaWindow  *window,
 
   g_free (*target);
 
-  if (!title)
+  if (!title || g_utf8_strlen (title, 2) < 1)
     *target = g_strdup ("");
   else if (g_utf8_strlen (title, MAX_TITLE_LENGTH + 1) > MAX_TITLE_LENGTH)
     {
