@@ -388,7 +388,7 @@ meta_workspace_activate_with_focus (MetaWorkspace *workspace,
 
   /* Note that old can be NULL; e.g. when starting up */
   old = workspace->screen->active_workspace;
-  
+
   /* Save old workspace, to be able to switch back. */
   workspace->screen->prev_workspace = old;
 
@@ -635,12 +635,14 @@ ensure_work_areas_validated (MetaWorkspace *workspace)
       workspace->xinerama_region[i] =
         meta_rectangle_get_minimal_spanning_set_for_region (
           &workspace->screen->xinerama_infos[i].rect,
-          workspace->all_struts);
+          workspace->all_struts,
+          FALSE);
     }
   workspace->screen_region =
     meta_rectangle_get_minimal_spanning_set_for_region (
       &workspace->screen->rect,
-      workspace->all_struts);
+      workspace->all_struts,
+      TRUE);
 
   /* STEP 3: Get the work areas (region-to-maximize-to) for the screen and
    *         xineramas.
@@ -968,7 +970,6 @@ meta_workspace_focus_default_window (MetaWorkspace *workspace,
                     "focus window may not be correct.\n");
     }
 
-
   if (meta_prefs_get_focus_mode () == META_FOCUS_MODE_CLICK ||
       !workspace->screen->display->mouse_mode)
     focus_ancestor_or_top_window (workspace, not_this_one, timestamp);
