@@ -155,6 +155,8 @@ void      meta_ui_pop_delay_exposes  (MetaUI *ui);
 
 GdkPixbuf* meta_ui_get_default_window_icon (MetaUI *ui);
 GdkPixbuf* meta_ui_get_default_mini_icon (MetaUI *ui);
+GdkPixbuf* meta_ui_get_window_icon_from_name (MetaUI *ui, char *name);
+GdkPixbuf* meta_ui_get_mini_icon_from_name (MetaUI *ui, char *name);
 
 gboolean  meta_ui_window_should_not_cause_focus (Display *xdisplay,
                                                  Window   xwindow);
