@@ -487,7 +487,6 @@ focus_in_event_cb (GtkWidget *window,
   return TRUE;
 }
 
-
 static gboolean
 focus_out_event_cb (GtkWidget *window,
                     GdkEvent  *event,
@@ -1051,7 +1050,7 @@ do_appwindow (GSimpleAction *action,
 
   contents = gtk_text_view_new ();
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (contents),
-                               PANGO_WRAP_WORD);
+                               GTK_WRAP_WORD);
 
   gtk_container_add (GTK_CONTAINER (sw),
                      contents);
