@@ -22,6 +22,8 @@
  */
 
 #include <config.h>
+#include <glib/gi18n.h>
+
 #include "util.h"
 #include "theme.h"
 #include "theme-parser.h"
@@ -31,10 +33,6 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <libintl.h>
-#define _(x) dgettext (GETTEXT_PACKAGE, x)
-#define N_(x) x
-
 /* We need to compute all different button arrangements
  * in terms of button location. We don't care about
  * different arrangements in terms of button function.
@@ -207,7 +205,7 @@ normal_contents (void)
 
   contents = gtk_text_view_new ();
   gtk_text_view_set_wrap_mode (GTK_TEXT_VIEW (contents),
-                               PANGO_WRAP_WORD);
+                               GTK_WRAP_WORD);
 
   gtk_container_add (GTK_CONTAINER (sw),
                      contents);
@@ -755,7 +753,6 @@ init_layouts (void)
 #endif
 }
 
-
 static GtkWidget*
 previews_of_button_layouts (void)
 {
@@ -974,7 +971,6 @@ main (int argc, char **argv)
   return 0;
 }
 
-
 static MetaFrameFlags
 get_flags (GtkWidget *widget)
 {
